@@ -268,7 +268,11 @@ QString KAboutLicense::text() const
     }
 
     if (knownLicense) {
+#ifndef Q_OS_ANDROID
         pathToFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf6/licenses/") + pathToFile);
+#else
+        pathToFile = QStringLiteral("assets:/share/kf6/licenses/") + pathToFile;
+#endif
         result += QCoreApplication::translate("KAboutLicense", "This program is distributed under the terms of the %1.").arg(name(KAboutLicense::ShortName));
         if (!pathToFile.isEmpty()) {
             result += lineFeed;
@@ -392,6 +396,7 @@ KAboutLicense KAboutLicense::byKeyword(const QString &rawKeyword)
     // Normalize keyword.
     QString keyword = rawKeyword;
     keyword = keyword.toLower();
+    keyword.replace(QLatin1StringView("-or-later"), QLatin1StringView("+"));
     keyword.remove(QLatin1Char(' '));
     keyword.remove(QLatin1Char('.'));
     keyword.remove(QLatin1Char('-'));
